pub struct Cff2Header<'a> {
data: FontData<'a>,
}Expand description
Compact Font Format (CFF) version 2 table header
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> Cff2Header<'a>
impl<'a> Cff2Header<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn major_version(&self) -> u8
pub fn major_version(&self) -> u8
Format major version (set to 2).
Sourcepub fn minor_version(&self) -> u8
pub fn minor_version(&self) -> u8
Format minor version (set to 0).
Sourcepub fn header_size(&self) -> u8
pub fn header_size(&self) -> u8
Header size (bytes).
Sourcepub fn top_dict_length(&self) -> u16
pub fn top_dict_length(&self) -> u16
Length of Top DICT structure in bytes.
Sourcepub fn top_dict_data(&self) -> &'a [u8] ⓘ
pub fn top_dict_data(&self) -> &'a [u8] ⓘ
Data containing the Top DICT.
Sourcepub fn trailing_data(&self) -> &'a [u8] ⓘ
pub fn trailing_data(&self) -> &'a [u8] ⓘ
Remaining table data.
pub fn major_version_byte_range(&self) -> Range<usize> ⓘ
pub fn minor_version_byte_range(&self) -> Range<usize> ⓘ
pub fn header_size_byte_range(&self) -> Range<usize> ⓘ
pub fn top_dict_length_byte_range(&self) -> Range<usize> ⓘ
pub fn _padding_byte_range(&self) -> Range<usize> ⓘ
pub fn top_dict_data_byte_range(&self) -> Range<usize> ⓘ
pub fn trailing_data_byte_range(&self) -> Range<usize> ⓘ